@@ -1,10 +1,12 @@
 import argparse
+from typing import Optional
 
 import annofabcli
 import annofabcli.common.cli
 import annofabcli.inspection_comment.delete_inspection_comments
 import annofabcli.inspection_comment.list_inspections_with_json
 import annofabcli.inspection_comment.put_inspection_comments
+import annofabcli.inspection_comment.put_inspection_comments_simply
 
 
 def parse_args(parser: argparse.ArgumentParser):
@@ -16,9 +18,10 @@ def parse_args(parser: argparse.ArgumentParser):
     annofabcli.inspection_comment.list_inspections.add_parser(subparsers)
     annofabcli.inspection_comment.list_inspections_with_json.add_parser(subparsers)
     annofabcli.inspection_comment.put_inspection_comments.add_parser(subparsers)
+    annofabcli.inspection_comment.put_inspection_comments_simply.add_parser(subparsers)
 
 
-def add_parser(subparsers: argparse._SubParsersAction):
+def add_parser(subparsers: Optional[argparse._SubParsersAction] = None):
     subcommand_name = "inspection_comment"
     subcommand_help = "検査コメント関係のサブコマンド"
     description = "検査コメント関係のサブコマンド"
@@ -27,3 +30,4 @@ def add_parser(subparsers: argparse._SubParsersAction):
         subparsers, subcommand_name, subcommand_help, description, is_subcommand=False
     )
     parse_args(parser)
+    return parser
